==> VVAS-DataCenter-core-6.0.0-sources.jar: com/viontech/keliu/model/ChannelSnapshot.java <==
package com.viontech.keliu.model;


import com.viontech.keliu.util.DateUtil;

import java.util.Date;

public class ChannelSnapshot {

    private String deviceSerialnum;
    private String channelSerialnum;
    private int width;
    private int height;
    private String type;
    private Date capttime;
    private String snapshot;
    private Long deviceId;
    private Long channelId;
    private Long gateId;
    private Long mallId;
    private Long accountId;
    private Date countdate;
    private Date counttime;
    private int hour;
    private String localIp;

    public String getLocalIp() {
        return localIp;
    }

    public void setLocalIp(String localIp) {
        this.localIp = localIp;
    }

    public String getDeviceSerialnum() {
        return deviceSerialnum;
    }

    public void setDeviceSerialnum(String deviceSerialnum) {
        this.deviceSerialnum = deviceSerialnum;
    }

    public String getChannelSerialnum() {
        return channelSerialnum;
    }

    public void setChannelSerialnum(String channelSerialnum) {
        this.channelSerialnum = channelSerialnum;
    }

    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getCapttime() {
        return capttime;
    }

    public void setCapttime(Date capttime) {
        this.capttime = capttime;
    }

    public String getSnapshot() {
        return snapshot;
    }

    public void setSnapshot(String snapshot) {
        this.snapshot = snapshot;
    }

    public Long getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(Long deviceId) {
        this.deviceId = deviceId;
    }

    public Long getChannelId() {
        return channelId;
    }

    public void setChannelId(Long channelId) {
        this.channelId = channelId;
    }

    public Long getGateId() {
        return gateId;
    }

    public void setGateId(Long gateId) {
        this.gateId = gateId;
    }

    public Long getMallId() {
        return mallId;
    }

    public void setMallId(Long mallId) {
        this.mallId = mallId;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Date getCountdate() {
        return countdate;
    }

    public void setCountdate(Date countdate) {
        this.countdate = countdate;
    }

    public Date getCounttime() {
        return counttime;
    }

    public void setCounttime(Date counttime) {
        this.counttime = counttime;
    }

    public int getHour() {
        return DateUtil.getHour(counttime);
    }

    public void setHour(int hour) {
        this.hour = hour;
    }
}

==> VVAS-DataCenter-core-6.1.4-sources.jar: com/viontech/keliu/model/ChannelSnapshot.java <==
package com.viontech.keliu.model;


import com.viontech.keliu.base.BaseModel;
import com.viontech.keliu.util.DateUtil;

import java.util.Date;

public class ChannelSnapshot extends BaseModel {

    private String deviceSerialnum;
    private String channelSerialnum;
    private int width;
    private int height;
    private String type;
    private Date capttime;
    private String snapshot;
    private Long deviceId;
    private Long channelId;
    private Long gateId;
    private Long mallId;
    private Long accountId;
    private Date countdate;
    private Date counttime;
    private int hour;
    private String localIp;

    public String getLocalIp() {
        return localIp;
    }

    public void setLocalIp(String localIp) {
        this.localIp = localIp;
    }

    public String getDeviceSerialnum() {
        return deviceSerialnum;
    }

    public void setDeviceSerialnum(String deviceSerialnum) {
        this.deviceSerialnum = deviceSerialnum;
    }

    public String getChannelSerialnum() {
        return channelSerialnum;
    }

    public void setChannelSerialnum(String channelSerialnum) {
        this.channelSerialnum = channelSerialnum;
    }

    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getCapttime() {
        return capttime;
    }

    public void setCapttime(Date capttime) {
        this.capttime = capttime;
    }

    public String getSnapshot() {
        return snapshot;
    }

    public void setSnapshot(String snapshot) {
        this.snapshot = snapshot;
    }

    public Long getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(Long deviceId) {
        this.deviceId = deviceId;
    }

    public Long getChannelId() {
        return channelId;
    }

    public void setChannelId(Long channelId) {
        this.channelId = channelId;
    }

    public Long getGateId() {
        return gateId;
    }

    public void setGateId(Long gateId) {
        this.gateId = gateId;
    }

    public Long getMallId() {
        return mallId;
    }

    public void setMallId(Long mallId) {
        this.mallId = mallId;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Date getCountdate() {
        return countdate;
    }

    public void setCountdate(Date countdate) {
        this.countdate = countdate;
    }

    public Date getCounttime() {
        return counttime;
    }

    public void setCounttime(Date counttime) {
        this.counttime = counttime;
    }

    public int getHour() {
        return DateUtil.getHour(counttime);
    }

    public void setHour(int hour) {
        this.hour = hour;
    }
}
